@@ -147,7 +147,7 @@ class ITrigger(aws_cdk.core.IConstruct, typing_extensions.Protocol):
 
 
 class _ITriggerProxy(
-    jsii.proxy_for(aws_cdk.core.IConstruct) # type: ignore[misc]
+    jsii.proxy_for(aws_cdk.core.IConstruct), # type: ignore[misc]
 ):
     '''Interface for triggers.'''
 
@@ -164,7 +164,7 @@ class _ITriggerProxy(
         '''
         if __debug__:
             type_hints = typing.get_type_hints(ITrigger.execute_after)
-            check_type(argname="argument scopes", value=scopes, expected_type=typing.Tuple[type_hints["scopes"], ...])
+            check_type(argname="argument scopes", value=scopes, expected_type=typing.Tuple[type_hints["scopes"], ...]) # pyright: ignore [reportGeneralTypeIssues]
         return typing.cast(None, jsii.invoke(self, "executeAfter", [*scopes]))
 
     @jsii.member(jsii_name="executeBefore")
@@ -178,7 +178,7 @@ class _ITriggerProxy(
         '''
         if __debug__:
             type_hints = typing.get_type_hints(ITrigger.execute_before)
-            check_type(argname="argument scopes", value=scopes, expected_type=typing.Tuple[type_hints["scopes"], ...])
+            check_type(argname="argument scopes", value=scopes, expected_type=typing.Tuple[type_hints["scopes"], ...]) # pyright: ignore [reportGeneralTypeIssues]
         return typing.cast(None, jsii.invoke(self, "executeBefore", [*scopes]))
 
 # Adding a "__jsii_proxy_class__(): typing.Type" function to the interface
@@ -258,7 +258,7 @@ class Trigger(
         '''
         if __debug__:
             type_hints = typing.get_type_hints(Trigger.execute_after)
-            check_type(argname="argument scopes", value=scopes, expected_type=typing.Tuple[type_hints["scopes"], ...])
+            check_type(argname="argument scopes", value=scopes, expected_type=typing.Tuple[type_hints["scopes"], ...]) # pyright: ignore [reportGeneralTypeIssues]
         return typing.cast(None, jsii.invoke(self, "executeAfter", [*scopes]))
 
     @jsii.member(jsii_name="executeBefore")
@@ -272,7 +272,7 @@ class Trigger(
         '''
         if __debug__:
             type_hints = typing.get_type_hints(Trigger.execute_before)
-            check_type(argname="argument scopes", value=scopes, expected_type=typing.Tuple[type_hints["scopes"], ...])
+            check_type(argname="argument scopes", value=scopes, expected_type=typing.Tuple[type_hints["scopes"], ...]) # pyright: ignore [reportGeneralTypeIssues]
         return typing.cast(None, jsii.invoke(self, "executeBefore", [*scopes]))
 
 
@@ -460,7 +460,7 @@ class TriggerFunction(
         '''
         if __debug__:
             type_hints = typing.get_type_hints(TriggerFunction.execute_after)
-            check_type(argname="argument scopes", value=scopes, expected_type=typing.Tuple[type_hints["scopes"], ...])
+            check_type(argname="argument scopes", value=scopes, expected_type=typing.Tuple[type_hints["scopes"], ...]) # pyright: ignore [reportGeneralTypeIssues]
         return typing.cast(None, jsii.invoke(self, "executeAfter", [*scopes]))
 
     @jsii.member(jsii_name="executeBefore")
@@ -474,10 +474,10 @@ class TriggerFunction(
         '''
         if __debug__:
             type_hints = typing.get_type_hints(TriggerFunction.execute_before)
-            check_type(argname="argument scopes", value=scopes, expected_type=typing.Tuple[type_hints["scopes"], ...])
+            check_type(argname="argument scopes", value=scopes, expected_type=typing.Tuple[type_hints["scopes"], ...]) # pyright: ignore [reportGeneralTypeIssues]
         return typing.cast(None, jsii.invoke(self, "executeBefore", [*scopes]))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="trigger")
     def trigger(self) -> Trigger:
         '''The underlying trigger resource.'''
